==> cscec5b-fbxt-impl-3.0.1-20220303.013330-61-sources.jar: com/ejianc/business/fbxt/odd/controller/OddSetController.java <==
package com.ejianc.business.fbxt.odd.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ejianc.business.fbxt.odd.bean.ReceiveEntity;
import com.ejianc.business.fbxt.odd.service.IReceiveService;
import com.ejianc.business.fbxt.odd.vo.ReceiveVO;
import com.ejianc.framework.core.exception.BusinessException;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import java.util.List;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.fbxt.odd.bean.OddSetEntity;
import com.ejianc.business.fbxt.odd.service.IOddSetService;
import com.ejianc.business.fbxt.odd.vo.OddSetVO;

/**
 * 分包协同设置实体
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("oddSet")
public class OddSetController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    
    @Autowired
    private IOddSetService service;
    @Autowired
    private IReceiveService receiveService;
    
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<OddSetVO> saveOrUpdate(@RequestBody OddSetVO saveorUpdateVO) {
    	OddSetEntity entity = BeanMapper.map(saveorUpdateVO, OddSetEntity.class);
        // 校验是否有接收人
        LambdaQueryWrapper<ReceiveEntity> query = new LambdaQueryWrapper<>();
        query.eq(ReceiveEntity::getSetId, saveorUpdateVO.getId());
        List<ReceiveEntity> entities =  receiveService.list(query);
        if (CollectionUtils.isNotEmpty(entities)){
            receiveService.removeByIds(entities.stream().map(ReceiveEntity::getId).collect(Collectors.toList()),true);
        }
    	service.saveOrUpdate(entity, false);
    	OddSetVO vo = BeanMapper.map(entity, OddSetVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    
    /**
     * @Description queryDetail 根据组织主键查询详情
     * @param orgId
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OddSetVO> queryDetail(Long orgId) {
        QueryParam queryParam = new QueryParam();
        queryParam.getParams().put("orgId", new Parameter(QueryParam.EQ, orgId));
    	List<OddSetEntity> list = service.queryList(queryParam,false);
    	OddSetVO vo = new OddSetVO();
    	if(CollectionUtils.isNotEmpty(list)){
            vo = BeanMapper.map(service.selectById(list.get(0).getId()), OddSetVO.class);
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<OddSetVO> vos) {
        service.removeByIds(vos.stream().map(OddSetVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<OddSetVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        
        IPage<OddSetEntity> page = service.queryPage(param,false);
        IPage<OddSetVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), OddSetVO.class));
        
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

}

==> cscec5b-fbxt-impl-3.0.1-20230507.052213-105-sources.jar: com/ejianc/business/fbxt/odd/controller/OddSetController.java <==
package com.ejianc.business.fbxt.odd.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ejianc.business.fbxt.odd.bean.ReceiveEntity;
import com.ejianc.business.fbxt.odd.service.IReceiveService;
import com.ejianc.business.fbxt.odd.vo.ReceiveVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.exception.BusinessException;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import java.util.List;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.fbxt.odd.bean.OddSetEntity;
import com.ejianc.business.fbxt.odd.service.IOddSetService;
import com.ejianc.business.fbxt.odd.vo.OddSetVO;

/**
 * 分包协同设置实体
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("oddSet")
public class OddSetController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IOrgApi orgApi;
    @Autowired
    private IOddSetService service;
    @Autowired
    private IReceiveService receiveService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<OddSetVO> saveOrUpdate(@RequestBody OddSetVO saveorUpdateVO) {
    	OddSetEntity entity = BeanMapper.map(saveorUpdateVO, OddSetEntity.class);
        entity.setOrgId(InvocationInfoProxy.getOrgId());
        // 校验是否有接收人
        LambdaQueryWrapper<ReceiveEntity> query = new LambdaQueryWrapper<>();
        query.eq(ReceiveEntity::getSetId, saveorUpdateVO.getId());
        List<ReceiveEntity> entities =  receiveService.list(query);
        if (CollectionUtils.isNotEmpty(entities)){
            receiveService.removeByIds(entities.stream().map(ReceiveEntity::getId).collect(Collectors.toList()),true);
        }
    	service.saveOrUpdate(entity, false);
    	OddSetVO vo = BeanMapper.map(entity, OddSetVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 根据组织主键查询详情
     * @param orgId
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OddSetVO> queryDetail(Long orgId) {
        QueryParam queryParam = new QueryParam();
        queryParam.getParams().put("orgId", new Parameter(QueryParam.EQ, orgId));
    	List<OddSetEntity> list = service.queryList(queryParam,false);
    	OddSetVO vo = new OddSetVO();
    	if(CollectionUtils.isNotEmpty(list)){
            vo = BeanMapper.map(service.selectById(list.get(0).getId()), OddSetVO.class);
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description queryDetail 根据组织主键查询详情
     * @param orgId
     */
    @RequestMapping(value = "/queryDetail2", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OddSetVO> queryDetail2(Long orgId) {
        CommonResponse<OrgVO> orgVo = orgApi.getOneById(orgId);
        OddSetVO vo = new OddSetVO();
        if(!orgVo.isSuccess()) {
            return CommonResponse.success("列表查询失败, 查询组织信息失败！");
        }
        if (null != orgVo.getData()) {
            if (orgVo.getData().getOrgType() == 5) {
                orgId = orgVo.getData().getParentId();
            }
            QueryParam queryParam = new QueryParam();
            queryParam.getParams().put("orgId", new Parameter(QueryParam.EQ, orgId));
            List<OddSetEntity> list = service.queryList(queryParam,false);
            if(CollectionUtils.isNotEmpty(list)){
                vo = BeanMapper.map(service.selectById(list.get(0).getId()), OddSetVO.class);
            }
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<OddSetVO> vos) {
        service.removeByIds(vos.stream().map(OddSetVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<OddSetVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        IPage<OddSetEntity> page = service.queryPage(param,false);
        IPage<OddSetVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), OddSetVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

}
